@@ -597,7 +597,7 @@ callback_exit_really (void)
 {
   score_write();
   option_write();
-  exit (0);
+  gtk_main_quit();
 }
 
 static void
@@ -609,7 +609,7 @@ callback_exit_with_lose ()
 	mb = NULL;
 }
 
-void
+gboolean
 callback_exit (GtkWidget *widget, GdkEvent *event)
 {
   if (!stalled
@@ -633,6 +633,8 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
       if (response == GTK_RESPONSE_YES)
       {
 	      callback_exit_with_lose();
+      } else {
+        return TRUE;
       }
     }
   else
@@ -669,7 +671,7 @@ callback_about (GtkWidget *widget, GdkEvent *event)
 	  char *filename = NULL;
 	  
 	  filename = gnome_program_locate_file (NULL,
-			  GNOME_FILE_DOMAIN_PIXMAP,
+			  GNOME_FILE_DOMAIN_APP_PIXMAP,
 			  "gnome-cardgame.png", FALSE, NULL);
 
 	  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
@@ -682,6 +684,7 @@ callback_about (GtkWidget *widget, GdkEvent *event)
 			   (const char **)documenters,
 			   strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			   pixbuf);
+  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (main_window));
   gtk_widget_show (about);
 }
 
