@@ -146,7 +146,7 @@ start_game(void)
 	active = -1;
 	target = -1;
 	inmove = -1;
-	snprintf(string, 19, "%d", score);
+	g_snprintf(string, 19, "%d", score);
 	gtk_label_set_text(GTK_LABEL(scorelabel), string);
 	set_inmove(0);
 }
@@ -611,7 +611,7 @@ check_goal(GtkWidget *widget, int num, int is_score)
 		{
 			char string[20];
 			score += addscore(count+1);
-			snprintf(string, 19, "%d", score);
+			g_snprintf(string, 19, "%d", score);
 			gtk_label_set_text(GTK_LABEL(scorelabel), string);
 		}
 
@@ -1168,7 +1168,7 @@ main (int argc, char *argv [])
 			      argc, argv,
 			      GNOME_PARAM_POPT_TABLE, NULL,
 			      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.xpm");
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/glines.png");
 	client = gnome_master_client ();
 
 	g_signal_connect (G_OBJECT (client), "save_yourself",
